@@ -159,59 +159,59 @@ structure(list(N = structure(list(Sex = c("Unisex", "Unisex",
     378867, 253943, 58587.1, 181008, 94794.7, 49886.8, 25646.8, 
     2977.22, 4846.56, 4426.82)), .Names = c("Sex", "Year", "Age", 
 "N"), row.names = c(NA, -340L), class = "data.frame"), B = structure(list(
-    Year = c(1971, 1972, 1973, 1974, 1975, 1976, 1977, 1978, 
-    1979, 1980, 1981, 1982, 1983, 1984, 1985, 1986, 1987, 1988, 
-    1989, 1990, 1991, 1992, 1993, 1994, 1995, 1996, 1997, 1998, 
-    1999, 2000, 2001, 2002, 2003, 2004), VB = c(1140000, 964964, 
-    761019, 722716, 778435, 825133, 1050000, 1270000, 1330000, 
-    1410000, 1190000, 940285, 775779, 780698, 827749, 769197, 
-    776460, 868580, 953567, 784715, 610520, 495860, 470127, 468598, 
-    518647, 577960, 682386, 708012, 646309, 550857, 525343, 561627, 
-    636831, 734505), SB = c(1370000, 1170000, 894552, 999547, 
-    966587, 1060000, 1480000, 1500000, 1630000, 1750000, 1410000, 
-    1130000, 918667, 1e+06, 1020000, 900452, 1090000, 1190000, 
-    1200000, 912646, 762816, 598591, 630708, 642020, 613469, 
-    737990, 906160, 828555, 817466, 623002, 700825, 737061, 808611, 
-    982954), Y = c(453052, 398528, 383446, 374770, 370991, 347849, 
-    340050, 330390, 368064, 434344, 468659, 388387, 300056, 283822, 
-    325267, 368633, 392257, 378076, 355954, 335390, 308560, 267767, 
-    251979, 178809, 169424, 181658, 203153, 242632, 260052, 235654, 
-    235098, 208830, 210000, NA), R = c(262806, 425777, 628953, 
-    207659, 360187, 401021, 229905, 234366, 186469, 328677, 213028, 
-    185820, 530062, 510445, 277039, 117558, 192850, 146381, 260156, 
-    232307, 103293, 242279, 301904, 112824, 226670, 66566.4, 
-    265870, 255701, 263285, 343564, 87727.6, 310215, 378867, 
-    NA)), .Names = c("Year", "VB", "SB", "Y", "R"), row.names = c(NA, 
--34L), class = "data.frame"), Sel = structure(list(Series = c("Gear 1", 
-"Gear 1", "Gear 1", "Gear 1", "Gear 1", "Gear 1", "Gear 1", "Gear 1", 
-"Gear 1", "Gear 1", "Survey 1", "Survey 1", "Survey 1", "Survey 1", 
-"Survey 1", "Survey 1", "Survey 1", "Survey 1", "Survey 1", "Survey 1", 
-"Maturity", "Maturity", "Maturity", "Maturity", "Maturity", "Maturity", 
-"Maturity", "Maturity", "Maturity", "Maturity"), Sex = c("Unisex", 
-"Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
-"Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
-"Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
-"Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
-"Unisex"), Age = c(1L, 2L, 3L, 4L, 5L, 6L, 7L, 8L, 9L, 10L, 1L, 
-2L, 3L, 4L, 5L, 6L, 7L, 8L, 9L, 10L, 1L, 2L, 3L, 4L, 5L, 6L, 
-7L, 8L, 9L, 10L), P = c(0.000465918, 0.0107437, 0.109044, 0.487138, 
-0.957858, 1, 0.999999, 0.999998, 0.999996, 0.999993, 0.093353, 
-0.30199, 0.656636, 0.959678, 1, 0.999999, 0.999998, 0.999996, 
-0.999994, 0.999991, 0, 0, 0, 1, 1, 1, 1, 1, 1, 1)), .Names = c("Series", 
-"Sex", "Age", "P"), row.names = c(NA, -30L), class = "data.frame"), 
-    Dev = structure(list(Initial = structure(c(-0.276004, -0.133551, 
-    -0.08248, 0.0879693, -0.161992, 0.19093, 0.323306, 0.082165
-    ), .Names = c("2", "3", "4", "5", "6", "7", "8", "9")), Annual = structure(c(0.904468, 
-    0.0370796, 0.544025, 0.98496, -0.145333, 0.411873, 0.501718, 
-    -0.107777, -0.0903785, -0.329944, 0.228531, -0.176938, -0.278815, 
-    0.808412, 0.753572, 0.138847, -0.693534, -0.235523, -0.526445, 
-    0.0482014, -0.0151754, -0.786165, 0.129073, 0.334609, -0.654477, 
-    0.0556041, -1.21763, 0.121238, 0.101377, 0.133603, 0.467231, 
-    -0.928844, 0.321739), .Names = c("1971", "1972", "1973", 
-    "1974", "1975", "1976", "1977", "1978", "1979", "1980", "1981", 
-    "1982", "1983", "1984", "1985", "1986", "1987", "1988", "1989", 
-    "1990", "1991", "1992", "1993", "1994", "1995", "1996", "1997", 
-    "1998", "1999", "2000", "2001", "2002", "2003"))), .Names = c("Initial", 
+    Year = 1971:2004, VB = c(1140000, 964964, 761019, 722716, 
+    778435, 825133, 1050000, 1270000, 1330000, 1410000, 1190000, 
+    940285, 775779, 780698, 827749, 769197, 776460, 868580, 953567, 
+    784715, 610520, 495860, 470127, 468598, 518647, 577960, 682386, 
+    708012, 646309, 550857, 525343, 561627, 636831, 734505), 
+    SB = c(1370000, 1170000, 894552, 999547, 966587, 1060000, 
+    1480000, 1500000, 1630000, 1750000, 1410000, 1130000, 918667, 
+    1e+06, 1020000, 900452, 1090000, 1190000, 1200000, 912646, 
+    762816, 598591, 630708, 642020, 613469, 737990, 906160, 828555, 
+    817466, 623002, 700825, 737061, 808611, 982954), Y = c(453052, 
+    398528, 383446, 374770, 370991, 347849, 340050, 330390, 368064, 
+    434344, 468659, 388387, 300056, 283822, 325267, 368633, 392257, 
+    378076, 355954, 335390, 308560, 267767, 251979, 178809, 169424, 
+    181658, 203153, 242632, 260052, 235654, 235098, 208830, 210000, 
+    NA), R = c(262806, 425777, 628953, 207659, 360187, 401021, 
+    229905, 234366, 186469, 328677, 213028, 185820, 530062, 510445, 
+    277039, 117558, 192850, 146381, 260156, 232307, 103293, 242279, 
+    301904, 112824, 226670, 66566.4, 265870, 255701, 263285, 
+    343564, 87727.6, 310215, 378867, NA)), .Names = c("Year", 
+"VB", "SB", "Y", "R"), row.names = c(NA, -34L), class = "data.frame"), 
+    Sel = structure(list(Series = c("Gear 1", "Gear 1", "Gear 1", 
+    "Gear 1", "Gear 1", "Gear 1", "Gear 1", "Gear 1", "Gear 1", 
+    "Gear 1", "Survey 1", "Survey 1", "Survey 1", "Survey 1", 
+    "Survey 1", "Survey 1", "Survey 1", "Survey 1", "Survey 1", 
+    "Survey 1", "Maturity", "Maturity", "Maturity", "Maturity", 
+    "Maturity", "Maturity", "Maturity", "Maturity", "Maturity", 
+    "Maturity"), Sex = c("Unisex", "Unisex", "Unisex", "Unisex", 
+    "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
+    "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
+    "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
+    "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
+    "Unisex", "Unisex"), Age = c(1L, 2L, 3L, 4L, 5L, 6L, 7L, 
+    8L, 9L, 10L, 1L, 2L, 3L, 4L, 5L, 6L, 7L, 8L, 9L, 10L, 1L, 
+    2L, 3L, 4L, 5L, 6L, 7L, 8L, 9L, 10L), P = c(0.000465918, 
+    0.0107437, 0.109044, 0.487138, 0.957858, 1, 0.999999, 0.999998, 
+    0.999996, 0.999993, 0.093353, 0.30199, 0.656636, 0.959678, 
+    1, 0.999999, 0.999998, 0.999996, 0.999994, 0.999991, 0, 0, 
+    0, 1, 1, 1, 1, 1, 1, 1)), .Names = c("Series", "Sex", "Age", 
+    "P"), row.names = c(NA, -30L), class = "data.frame"), Dev = structure(list(
+        Initial = structure(c(-0.276004, -0.133551, -0.08248, 
+        0.0879693, -0.161992, 0.19093, 0.323306, 0.082165), .Names = c("2", 
+        "3", "4", "5", "6", "7", "8", "9")), Annual = structure(c(0.904468, 
+        0.0370796, 0.544025, 0.98496, -0.145333, 0.411873, 0.501718, 
+        -0.107777, -0.0903785, -0.329944, 0.228531, -0.176938, 
+        -0.278815, 0.808412, 0.753572, 0.138847, -0.693534, -0.235523, 
+        -0.526445, 0.0482014, -0.0151754, -0.786165, 0.129073, 
+        0.334609, -0.654477, 0.0556041, -1.21763, 0.121238, 0.101377, 
+        0.133603, 0.467231, -0.928844, 0.321739), .Names = c("1971", 
+        "1972", "1973", "1974", "1975", "1976", "1977", "1978", 
+        "1979", "1980", "1981", "1982", "1983", "1984", "1985", 
+        "1986", "1987", "1988", "1989", "1990", "1991", "1992", 
+        "1993", "1994", "1995", "1996", "1997", "1998", "1999", 
+        "2000", "2001", "2002", "2003"))), .Names = c("Initial", 
     "Annual")), Survey = structure(list(Series = c(1L, 1L, 1L, 
     1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 
     1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 
@@ -664,4 +664,4 @@ structure(list(N = structure(list(Sex = c("Unisex", "Unisex",
         0.0118643)), .Names = c("Series", "Year", "SS", "Sex", 
     "Age", "Obs", "Fit"), row.names = c(NA, -190L), class = "data.frame")), .Names = c("N", 
 "B", "Sel", "Dev", "Survey", "CAc", "CAs"), call = quote(importCol(res.file = "c:/scape/example/cod.res", 
-    Dev = T, Survey = T, CAc = T, CAs = T)), scape.version = "1.1-4", info = "", class = "scape")
+    Dev = T, Survey = T, CAc = T, CAs = T)), scape.version = "1.1-5", info = "", class = "scape")
