@@ -127,69 +127,65 @@ structure(list(N = structure(list(Sex = c("Unisex", "Unisex",
 6286.53, 11052.3, 43248.5, 132697, 66222.2, 84525.9, 32883.4, 
 52743.5, 10473.3, 20975.7, 22104.1, 1919.9, 3840.71, 33174.7)), .Names = c("Sex", 
 "Year", "Age", "N"), row.names = c(NA, -275L), class = "data.frame"), 
-    B = structure(list(Year = c(1979, 1980, 1981, 1982, 1983, 
-    1984, 1985, 1986, 1987, 1988, 1989, 1990, 1991, 1992, 1993, 
-    1994, 1995, 1996, 1997, 1998, 1999, 2000, 2001, 2002, 2003
-    ), VB = c(131690, 102328, 78202.7, 81762.9, 98222.7, 103435, 
-    93393.3, 82795, 74156.8, 66999.4, 61316.9, 48023.5, 49651.9, 
-    41522.6, 40712, 106922, 169675, 188673, 174776, 161236, 151664, 
-    141758, 134561, 125483, 108262), SB = c(144912, 112910, 86131, 
-    89790.7, 106502, 112214, 102675, 91262.4, 81174.9, 73292.2, 
-    67014.5, 51936.8, 54155.3, 44591.2, 44066.9, 115982, 180145, 
-    206647, 192110, 177517, 165516, 155116, 147828, 136696, 118563
-    ), Y = c(25305, 12828, 5989, 7915, 12803, 10777, 7490, 15252, 
-    12804, 17422, 26611, 16542, 21314, 14208, 9316, 11668, 10436, 
-    16504, 18923, 27164, 27205, 18409, 29999, 31847, NA), R = c(165808, 
-    179990, 41363, 8369.18, 56502.2, 47015.9, 45379.5, 101929, 
-    44995.9, 122039, 8233.83, 64160.3, 900649, 186203, 80228, 
-    29719.9, 242767, 156472, 53870, 183414, 71792.6, 127945, 
-    80898.8, 132697, NA)), .Names = c("Year", "VB", "SB", "Y", 
-    "R"), row.names = c(NA, -25L), class = "data.frame"), Sel = structure(list(
-        Series = c("Gear 1", "Gear 1", "Gear 1", "Gear 1", "Gear 1", 
-        "Gear 1", "Gear 1", "Gear 1", "Gear 1", "Gear 1", "Gear 1", 
-        "Survey 1", "Survey 1", "Survey 1", "Survey 1", "Survey 1", 
-        "Survey 1", "Survey 1", "Survey 1", "Survey 1", "Survey 1", 
-        "Survey 1", "Maturity", "Maturity", "Maturity", "Maturity", 
-        "Maturity", "Maturity", "Maturity", "Maturity", "Maturity", 
-        "Maturity", "Maturity"), Sex = c("Unisex", "Unisex", 
-        "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
-        "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
-        "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
-        "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
-        "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
-        "Unisex"), Age = c(1L, 2L, 3L, 4L, 5L, 6L, 7L, 8L, 9L, 
-        10L, 11L, 1L, 2L, 3L, 4L, 5L, 6L, 7L, 8L, 9L, 10L, 11L, 
-        1L, 2L, 3L, 4L, 5L, 6L, 7L, 8L, 9L, 10L, 11L), P = c(0.000722682, 
-        0.0562608, 0.609665, 1, 0.999999, 0.999998, 0.999997, 
-        0.999994, 0.999991, 0.999988, 0.999984, 0, 0, 0, 1, 1, 
-        0.999999, 0.999997, 0.999995, 0.999992, 0.999989, 0.999985, 
-        0, 0.0500001084745763, 0.600000739281345, 0.950000460358527, 
-        1, 1, 1, 1, 1, 1, 1)), .Names = c("Series", "Sex", "Age", 
-    "P"), row.names = c(NA, -33L), class = "data.frame"), Dev = structure(list(
-        Initial = structure(c(-0.615429, -0.400785, 0.876576, 
-        0.00762806, -0.221926, 0.120723, 0.723673, -0.115298, 
-        0.225449), .Names = c("2", "3", "4", "5", "6", "7", "8", 
-        "9", "10")), Annual = structure(c(-0.600611, 0.719962, 
-        0.815184, -0.637111, -2.23805, -0.339889, -0.526867, 
-        -0.556781, 0.260493, -0.548288, 0.45809, -2.22976, -0.149204, 
-        2.48759, 0.93586, 0.0955285, -0.987471, 1.09206, 0.647962, 
-        -0.415831, 0.812267, -0.122915, 0.457657, 0.00141056), .Names = c("1979", 
-        "1980", "1981", "1982", "1983", "1984", "1985", "1986", 
-        "1987", "1988", "1989", "1990", "1991", "1992", "1993", 
-        "1994", "1995", "1996", "1997", "1998", "1999", "2000", 
-        "2001", "2002"))), .Names = c("Initial", "Annual")), 
-    Survey = structure(list(Series = c(1L, 1L, 1L, 1L, 1L, 1L, 
+    B = structure(list(Year = 1979:2003, VB = c(131690, 102328, 
+    78202.7, 81762.9, 98222.7, 103435, 93393.3, 82795, 74156.8, 
+    66999.4, 61316.9, 48023.5, 49651.9, 41522.6, 40712, 106922, 
+    169675, 188673, 174776, 161236, 151664, 141758, 134561, 125483, 
+    108262), SB = c(144912, 112910, 86131, 89790.7, 106502, 112214, 
+    102675, 91262.4, 81174.9, 73292.2, 67014.5, 51936.8, 54155.3, 
+    44591.2, 44066.9, 115982, 180145, 206647, 192110, 177517, 
+    165516, 155116, 147828, 136696, 118563), Y = c(25305, 12828, 
+    5989, 7915, 12803, 10777, 7490, 15252, 12804, 17422, 26611, 
+    16542, 21314, 14208, 9316, 11668, 10436, 16504, 18923, 27164, 
+    27205, 18409, 29999, 31847, NA), R = c(165808, 179990, 41363, 
+    8369.18, 56502.2, 47015.9, 45379.5, 101929, 44995.9, 122039, 
+    8233.83, 64160.3, 900649, 186203, 80228, 29719.9, 242767, 
+    156472, 53870, 183414, 71792.6, 127945, 80898.8, 132697, 
+    NA)), .Names = c("Year", "VB", "SB", "Y", "R"), row.names = c(NA, 
+    -25L), class = "data.frame"), Sel = structure(list(Series = c("Gear 1", 
+    "Gear 1", "Gear 1", "Gear 1", "Gear 1", "Gear 1", "Gear 1", 
+    "Gear 1", "Gear 1", "Gear 1", "Gear 1", "Survey 1", "Survey 1", 
+    "Survey 1", "Survey 1", "Survey 1", "Survey 1", "Survey 1", 
+    "Survey 1", "Survey 1", "Survey 1", "Survey 1", "Maturity", 
+    "Maturity", "Maturity", "Maturity", "Maturity", "Maturity", 
+    "Maturity", "Maturity", "Maturity", "Maturity", "Maturity"
+    ), Sex = c("Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
+    "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
+    "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
+    "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
+    "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", "Unisex", 
+    "Unisex", "Unisex", "Unisex", "Unisex"), Age = c(1L, 2L, 
+    3L, 4L, 5L, 6L, 7L, 8L, 9L, 10L, 11L, 1L, 2L, 3L, 4L, 5L, 
+    6L, 7L, 8L, 9L, 10L, 11L, 1L, 2L, 3L, 4L, 5L, 6L, 7L, 8L, 
+    9L, 10L, 11L), P = c(0.000722682, 0.0562608, 0.609665, 1, 
+    0.999999, 0.999998, 0.999997, 0.999994, 0.999991, 0.999988, 
+    0.999984, 0, 0, 0, 1, 1, 0.999999, 0.999997, 0.999995, 0.999992, 
+    0.999989, 0.999985, 0, 0.0500001084745763, 0.600000739281345, 
+    0.950000460358527, 1, 1, 1, 1, 1, 1, 1)), .Names = c("Series", 
+    "Sex", "Age", "P"), row.names = c(NA, -33L), class = "data.frame"), 
+    Dev = structure(list(Initial = structure(c(-0.615429, -0.400785, 
+    0.876576, 0.00762806, -0.221926, 0.120723, 0.723673, -0.115298, 
+    0.225449), .Names = c("2", "3", "4", "5", "6", "7", "8", 
+    "9", "10")), Annual = structure(c(-0.600611, 0.719962, 0.815184, 
+    -0.637111, -2.23805, -0.339889, -0.526867, -0.556781, 0.260493, 
+    -0.548288, 0.45809, -2.22976, -0.149204, 2.48759, 0.93586, 
+    0.0955285, -0.987471, 1.09206, 0.647962, -0.415831, 0.812267, 
+    -0.122915, 0.457657, 0.00141056), .Names = c("1979", "1980", 
+    "1981", "1982", "1983", "1984", "1985", "1986", "1987", "1988", 
+    "1989", "1990", "1991", "1992", "1993", "1994", "1995", "1996", 
+    "1997", "1998", "1999", "2000", "2001", "2002"))), .Names = c("Initial", 
+    "Annual")), Survey = structure(list(Series = c(1L, 1L, 1L, 
     1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 
-    1L, 1L, 1L, 1L), Year = 1979:2003, Obs = c(NA, NA, NA, NA, 
-    NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, 24033, 28841, 130535, 
-    NA, NA, 167668, NA, 135612, NA, 152799, NA), CV = c(NA, NA, 
-    NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, 0.21, 0.36, 
-    0.3, NA, NA, 0.18, NA, 0.17, NA, 0.68, NA), Fit = c(131132, 
-    101753, 76179.8, 63659.7, 77767.5, 99650.3, 92735.1, 76805.8, 
-    68144.5, 60860.9, 48915, 42275.8, 36504.8, 40120.1, 26655.2, 
-    33008.6, 153798, 181734, 171010, 144240, 138038, 135669, 
-    116150, 116800, 92971.4)), .Names = c("Series", "Year", "Obs", 
-    "CV", "Fit"), row.names = c(NA, -25L), class = "data.frame"), 
+    1L, 1L, 1L, 1L, 1L, 1L, 1L), Year = 1979:2003, Obs = c(NA, 
+    NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, 24033, 
+    28841, 130535, NA, NA, 167668, NA, 135612, NA, 152799, NA
+    ), CV = c(NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, 
+    NA, NA, 0.21, 0.36, 0.3, NA, NA, 0.18, NA, 0.17, NA, 0.68, 
+    NA), Fit = c(131132, 101753, 76179.8, 63659.7, 77767.5, 99650.3, 
+    92735.1, 76805.8, 68144.5, 60860.9, 48915, 42275.8, 36504.8, 
+    40120.1, 26655.2, 33008.6, 153798, 181734, 171010, 144240, 
+    138038, 135669, 116150, 116800, 92971.4)), .Names = c("Series", 
+    "Year", "Obs", "CV", "Fit"), row.names = c(NA, -25L), class = "data.frame"), 
     CAc = structure(list(Series = c(1L, 1L, 1L, 1L, 1L, 1L, 1L, 
     1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 
     1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 
@@ -401,4 +397,4 @@ structure(list(N = structure(list(Sex = c("Unisex", "Unisex",
     "Year", "SS", "Sex", "Age", "Obs", "Fit"), row.names = c(NA, 
     -253L), class = "data.frame")), .Names = c("N", "B", "Sel", 
 "Dev", "Survey", "CAc"), call = quote(importCol(res.file = "c:/scape/example/sbw.res", 
-    Dev = T, Survey = T, CAc = T)), scape.version = "1.1-4", info = "", class = "scape")
+    Dev = T, Survey = T, CAc = T)), scape.version = "1.1-5", info = "", class = "scape")
